//The same way DTWClassifier and KNNClassifier are similar yet different applies between DTWRegressor and KNNRegressor. DTW is used to find the K nearest neighbours of a target from a bundle of pairs of series in the input, and points in the output, fitting a DataSeries to a DataSet. From the K nearest neighbough, an interpolation is done on the K points of the datasets, weighted by the distance of the same-named series in the dataseries to the query series. Let's make a simple example to illustrate.

//1. execute the codeblock below
(
~xypoint = Buffer.alloc(s,2);
~pointOut = Buffer.alloc(s,10);
~entry = FluidDataSet(s);
~gestureXY = Buffer(s);
~count = 0;
~series = FluidDataSeries(s);
~points = FluidDataSet(s);
~dtwr = FluidDTWRegressor(s);
~makingEntries = true;

SynthDef(\writer, {var trig = Impulse.kr(50); FluidDataSetWr.kr(~entry, buf: ~xypoint, idNumber: PulseCount.kr(trig),trig:trig)}).send;

w = Window("DTWRegressor", Rect(top: Window.screenBounds.height-400, width: 800,height: 400)).front;

~ms = MultiSliderView(w,Rect(top: 100,width: 400, height: 300)).size_(10).elasticMode_(1).isFilled_(1).action_{
	arg ms;
	if (~makingEntries, {~pointOut.setn(0,ms.value)});
}.value_(0.5.dup(10));

FluidPlotter(w, Rect(left: 400, width: 400, height: 400), standalone: false, mouseMoveAction: {|...in|
	if (in[5].notNil, {
		//clear the ds
		~entry.clear;
		in[0].dict = Dictionary.newFrom(["cols",2,"data",Dictionary.newFrom([])]);
		//write the value to buf
		~xypoint.setn(0,in[[1,2]]);
		//start the writer function that has a constant frequency
		~timedWriter = Synth(\writer);
	}, {
		if (in[4].notNil, {
			//stop the writer function
			~timedWriter.free;
			//transfer to buf
			~entry.toBuffer(~gestureXY,action: {
				if (~makingEntries, {
					//make an entry in the FluidDataSeries with a given identifier
					~series.addSeries(~count.asSymbol, ~gestureXY);
					//and make an entry in the FluidDataSet with the same identifier
					~points.addPoint(~count.asSymbol, ~pointOut);
				},{
					~dtwr.predictSeries(~gestureXY, ~pointOut, {
						~pointOut.getn(0,10,{
							arg prediction;
							defer{
								~ms.value_(prediction);
							}
						});
					});
				});

			});
		}, {
			~xypoint.setn(0,in[[1,2]]);
			in[0].addPoint_(~count.asSymbol,in[1],in[2]);
			~count = ~count + 1;
		});
	});
})
)

// 2. do this sequence 3 times:
// 2.1 - make a shape on the multislider on the left
// 2.2 - draw a few instances of a gesture in the FluidPlotter you would like to associate with this data

// 3. change to query mode
~makingEntries = false;

// 4. fit the data
~dtwr.fit(~series,~points)

// 6. draw a gesture in the FluidPlotter: an interpolated set of values appear in the multislider